fnss.traffic.trafficmatrices.TrafficMatrixSequence.pop — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »

# fnss.traffic.trafficmatrices.TrafficMatrixSequence.pop

`TrafficMatrixSequence.` `pop`(i)

  Removes the traffic matrix in a specific position of the sequence

  Parameters : | i : int The index of the traffic matrix to remove
  Returns : | tm : TrafficMatrix The TrafficMatrix popped from the sequence
  Raises : | IndexError : if list is empty or index is out of range.

  Examples

      >>> import fnss
      >>> tms = fnss.TrafficMatrixSequence()
      >>> tm = TrafficMatrix()
      >>> tms.append(tm)
      >>> tms.remove(tm)

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »